@@ -3,7 +3,7 @@ use Any::Moose;
 extends 'Path::Dispatcher::Rule';
 
 has dispatcher => (
-    is       => 'rw',
+    is       => 'ro',
     isa      => 'Path::Dispatcher',
     required => 1,
     handles  => ['rules', 'complete'],
@@ -17,8 +17,6 @@ sub match {
     return $dispatch->matches;
 }
 
-sub readable_attributes { shift->dispatcher->name }
-
 __PACKAGE__->meta->make_immutable;
 no Any::Moose;
 
